@@ -65,7 +65,13 @@ class AutocompleteView(generic.View):
 
 
 class CreateView(generic.CreateView):
+    """Simple wrapper for generic.CreateView, that responds to _popup."""
+
     def form_valid(self, form):
+        """ If request.GET._popup, return some javascript. """
+        if self.request.GET.get('_popup', False):
+            self.success_url = '/'  # avoid ImproperlyConfigured
+
         response = super(CreateView, self).form_valid(form)
 
         if not self.request.GET.get('_popup', False):
