@@ -97,8 +97,9 @@ class WidgetBase(object):
 
         autocomplete_name = self.autocomplete_name.lower()
         return safestring.mark_safe(render_to_string([
+            getattr(autocomplete, 'widget_template', ''),
             'autocomplete_light/%s/widget.html' % autocomplete_name,
-            'autocomplete_light/%s/widget.html' % getattr(autocomplete_name,
+            'autocomplete_light/%s/widget.html' % getattr(autocomplete,
                 'widget_template_name', ''),
             'autocomplete_light/widget.html',
         ], {
